package	jp.co.sds_corp.util.daemon.remote.rmi;

import java.util.Map;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.IService;
import jp.co.sds_corp.util.daemon.core.IDaemon;
import jp.co.sds_corp.util.daemon.core.Interval;
import jp.co.sds_corp.util.daemon.core.Schedule;
import jp.co.sds_corp.util.remote.AuthKey;
import jp.co.sds_corp.util.remote.ProcessRemoteControl;

/**
* デーモンマネージャのRMI I/F定義です。
*/
public interface DaemonRemote extends ProcessRemoteControl
{
	/**
	* 全てのデーモンを開始します。
	* @param	key		RMI 認証キー
	*/
	public void start( AuthKey key ) throws Exception;
	/**
	* 指定された名前のデーモンを開始します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	*/
	public void start( AuthKey key, String name ) throws Exception;

	/**
	* 全てのデーモンを停止します。
	* @param	key		RMI 認証キー
	*/
	public void stop( AuthKey key ) throws Exception;
	/**
	* 指定された名前のデーモンを停止します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	*/
	public void stop( AuthKey key, String name ) throws Exception;

	/**
	* 全てのデーモンを停止して、デーモンマネージャーを終了します。
	* @param	key		RMI 認証キー
	*/
	public void quit( AuthKey key ) throws Exception;

	/**
	* 全てのデーモンの情報を再読み込みします。
	* @param	key		RMI 認証キー
	*/
	public void reload( AuthKey key ) throws Exception;

	/**
	* 全てのデーモンを初期化します。
	* @param	key		RMI 認証キー
	*/
	public void initialize( AuthKey key ) throws Exception;
	/**
	* 指定された名前のデーモンを初期化します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	*/
	public void initialize( AuthKey key, String name ) throws Exception;

	/**
	* 全てのデーモンの情報を文字列で取得します。
	* @param	key		RMI 認証キー
	*/
	public Object status( AuthKey key ) throws Exception;
	/**
	* 指定された名前のデーモンの情報を文字列で取得します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	*/
	public Object status( AuthKey key, String name ) throws Exception;

	/**
	* 全ての Thread の情報を文字列で取得します。
	* @param	key		RMI 認証キー
	*/
	public Object thread( AuthKey key ) throws Exception;
	/**
	* JVMの情報を文字列で取得します。
	* @param	key		RMI 認証キー
	*/
	public Object vminfo( AuthKey key ) throws Exception;
	/**
	* JVMの情報を文字列で取得します。
	* @param	key		RMI 認証キー
	*/
	public Object properties( AuthKey key ) throws Exception;
	/**
	* Garbage Collectionを実施します。
	* @param	key		RMI 認証キー
	*/
	public void gc( AuthKey key ) throws Exception;

	/**
	* 設定情報を出力します。
	* @param	key		RMI 認証キー
	*/
	public void save( AuthKey key, String file, String name ) throws Exception;

	/**
	* サービスの一覧を返します。
	* @param	key		RMI 認証キー
	* @return	サービスの一覧
	*/
	public Map getServiceMap( AuthKey key ) throws Exception;
	/**
	* 指定された名前のサービスを返します。
	* @param    key     RMI 認証キー
	* @param    name    サービスの名前
	* @return   指定されたサービス
	*/
	public IService getService( AuthKey key, String name ) throws Exception;
	/**
	* 指定された名前のサービスの状態を返します。
	* @param    key     RMI 認証キー
	* @param    name    サービスの名前
	* @return   指定されたサービス
	*/
	public IService.Status getServiceStatus( AuthKey key, String name )
		throws Exception;

	/**
	* デーモンの一覧を返します。
	* @param	key		RMI 認証キー
	* @return	デーモンの一覧
	*/
	public Map getDaemonMap( AuthKey key ) throws Exception;
	/**
	* 指定された名前のデーモンを返します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	* @return	指定されたデーモン
	*/
	public IDaemon getDaemon( AuthKey key, String name ) throws Exception;
	/**
	* 指定された名前のデーモンの状態を返します。
	* @param    key     RMI 認証キー
	* @param    name    デーモンの名前
	* @return   指定されたデーモン
	*/
	public IDaemon.Status getDaemonStatus( AuthKey key, String name )
		throws Exception;

	/**
	* 全てのデーモンの情報を文字列で取得します。
	* @param	key		RMI 認証キー
	*/
	public IDaemon addDaemon( AuthKey key, IConfiguration config )
		throws Exception;

	/**
	* 指定された名前のデーモンを返します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	* @return	指定されたデーモン
	*/
	public Object invokeDaemon( AuthKey key, String name, String method )
		throws Exception;

	/**
	* CronDaemonにスケジュールを追加します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	* @param	sch		スケジュール
	*/
	public void addSchedule( AuthKey key, String name, Schedule sch )
		throws Exception;

	/**
	* CronDaemonのスケジュールを削除します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	* @param	idx		削除するスケジュールのインデックス
	* @return	削除されたスケジュール
	*/
	public Schedule removeSchedule( AuthKey key, String name, Integer idx )
		throws Exception;

	/**
	* TimerDaemonに間隔を追加します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	* @param	itv		間隔
	*/
	public void addInterval( AuthKey key, String name, Interval itv )
		throws Exception;

	/**
	* TimerDaemonの間隔を削除します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	* @param	idx		削除するスケジュールのインデックス
	* @return	削除されたスケジュール
	*/
	public Interval removeInterval( AuthKey key, String name, Integer idx )
		throws Exception;

	/**
	* CronDaemon,TimerDaemonの処理を直ちに実行します。
	* @param	key		RMI 認証キー
	* @param	name	デーモンの名前
	*/
	public void startImmediate( AuthKey key, String name )
		throws Exception;

	/**
	* helpを表示します。
	* @param	key		RMI 認証キー
	*/
	public Object help( AuthKey key ) throws Exception;
}
